==> huaweicloudsdkcoc-3.1.140-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/show_slo_detail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowSloDetailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'slo_id': 'str'
    }

    attribute_map = {
        'slo_id': 'slo_id'
    }

    def __init__(self, slo_id=None):
        """ShowSloDetailRequest

        The model defined in huaweicloud sdk

        :param slo_id: SLO的ID
        :type slo_id: str
        """
        
        

        self._slo_id = None
        self.discriminator = None

        self.slo_id = slo_id

    @property
    def slo_id(self):
        """Gets the slo_id of this ShowSloDetailRequest.

        SLO的ID

        :return: The slo_id of this ShowSloDetailRequest.
        :rtype: str
        """
        return self._slo_id

    @slo_id.setter
    def slo_id(self, slo_id):
        """Sets the slo_id of this ShowSloDetailRequest.

        SLO的ID

        :param slo_id: The slo_id of this ShowSloDetailRequest.
        :type slo_id: str
        """
        self._slo_id = slo_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowSloDetailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.144-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/show_slo_detail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowSloDetailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'slo_id': 'str'
    }

    attribute_map = {
        'slo_id': 'slo_id'
    }

    def __init__(self, slo_id=None):
        r"""ShowSloDetailRequest

        The model defined in huaweicloud sdk

        :param slo_id: SLO的ID
        :type slo_id: str
        """
        
        

        self._slo_id = None
        self.discriminator = None

        self.slo_id = slo_id

    @property
    def slo_id(self):
        r"""Gets the slo_id of this ShowSloDetailRequest.

        SLO的ID

        :return: The slo_id of this ShowSloDetailRequest.
        :rtype: str
        """
        return self._slo_id

    @slo_id.setter
    def slo_id(self, slo_id):
        r"""Sets the slo_id of this ShowSloDetailRequest.

        SLO的ID

        :param slo_id: The slo_id of this ShowSloDetailRequest.
        :type slo_id: str
        """
        self._slo_id = slo_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowSloDetailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
